@@ -1,14 +1,17 @@
 import ast
 import os
+import inspect
 from datetime import datetime as dt
 from typing import Any, Callable, Union
 
 import pendulum
 import yaml
 
-from ..config.interface import ConfigInterface
+from expandvars import expand
+from ..config.interface import ConfigInterface, mapped_config
 from ..core.exceptions import ExecutionException
 from ..core.settings import get_settings
+from ..config.mapping import config_map
 from ..engine import Engine
 from ..execution.schedule import Schedule
 from ..experiment.experiment import Experiment
@@ -66,12 +69,14 @@ class Execution(Jsonable):
         self.code_version = None
         self.started_at = None
 
-        if callable(experiment):
+        if not isinstance(experiment, Experiment) and (
+            inspect.isclass(experiment) or callable(experiment)
+        ):
             # decorator use
-            if None not in (storage, engine, project, seed):
+            if None not in (storage, engine, index, project, seed):
                 raise ValueError(
                     "Execution decorator takes no arguments; "
-                    "call the decorated function with arguments instead."
+                    "call the decorated object with arguments instead."
                 )
             self.function = experiment
             return
@@ -86,11 +91,14 @@ class Execution(Jsonable):
         self._behavior = {"raise_exceptions": False}
         self.failures = 0
 
-    def __call__(self, experiment, storage=None, engine=None, project=None, seed=None):
+    def __call__(
+        self, experiment, storage=None, engine=None, index=None, project=None, seed=None
+    ):
+        self.set_project(project)
         self.set_storage(storage)
         self.set_experiment(experiment)
         self.set_engine(engine)
-        self.set_project(project)
+        self.set_index(index)
         self.set_seed(seed)
         if self.function is not None:
             # decorator invocation
@@ -128,32 +136,6 @@ class Execution(Jsonable):
     def set_experiment(self, experiment):
         self.experiment = Experiment.create(experiment)
 
-        # experiment directory
-        experiment_directory = self.experiment.specification.get("directory", None)
-        if experiment_directory is None:
-            experiment_directory = get_settings()["default_directory"]
-        if isinstance(experiment_directory, str):
-            # replace magic variables
-            if experiment_directory.find("&PROJECT") != -1:
-                project_name = self.project.name if self.project else ""
-                experiment_directory = experiment_directory.replace(
-                    "&PROJECT", project_name.replace(".", "/")
-                )
-            if experiment_directory.find("&MODULE") != -1:
-                module_name = (
-                    self.experiment._resolved_module_origin
-                    if hasattr(self.experiment, "_resolved_module_origin")
-                    else ""
-                )
-                experiment_directory = experiment_directory.replace(
-                    "&MODULE", module_name
-                )
-            try:
-                experiment_directory = dt.now().strftime(experiment_directory)
-            except ValueError:
-                pass
-            self.storage.config["directory"] = experiment_directory.strip("/")
-
         return self
 
     def set_storage(self, storage):
@@ -215,24 +197,44 @@ class Execution(Jsonable):
         for index, (node, components, resources) in enumerate(
             parse_experiment(self.experiment, seed=self.seed)
         ):
-            node_config, components_config = config.get(node, components)
+            component_config, components_config = config.get(node, components)
 
             # compute resources
-            if callable(resources):
-                resources = config.call_with_context(
-                    resources, node_config, components_config
+            if isinstance(self.engine, Engine) and not self.engine.supports_resources():
+                if resources is not None:
+                    msg(
+                        "Engine does not support resource specification. Skipping ...",
+                        level="warn",
+                        color="header",
+                    )
+                    resources = None
+            elif callable(resources):
+                resources = resources(
+                    engine=self.engine,
+                    component=mapped_config(component_config),
+                    components=[
+                        mapped_config(component) for component in components_config
+                    ],
+                )
+            elif resources is None:
+                resources = Registration.get().default_resources(
+                    engine=self.engine,
+                    component=mapped_config(component_config),
+                    components=[
+                        mapped_config(component) for component in components_config
+                    ],
                 )
 
             if "tune" in self.experiment.specification:
                 self.schedule.add_tune(
-                    component=node_config,
+                    component=component_config,
                     components=components_config,
                     resources=resources,
                     **self.experiment.specification["tune"]["arguments"],
                 )
             else:
                 self.schedule.add_execute(
-                    component=node_config,
+                    component=component_config,
                     components=components_config,
                     resources=resources,
                 )
@@ -289,6 +291,33 @@ class Execution(Jsonable):
         self.failures = 0
         self.storage.config["experiment"] = self.experiment_id
 
+        # expand variables in storage directory
+        if isinstance(self.storage.config["directory"], str):
+            # % variables
+            variables = dict()
+            try:
+                variables["PROJECT"] = self.project.name if self.project else None
+            except (KeyError, ValueError):
+                variables["PROJECT"] = None
+
+            variables["EXPERIMENT"] = (
+                self.experiment.specification["name"] if self.experiment else ""
+            )
+
+            self.storage.config["directory"] = expand(
+                self.storage.config["directory"], environ=variables, var_symbol="&"
+            )
+            # strftime variables
+            try:
+                self.storage.config["directory"] = dt.now().strftime(
+                    self.storage.config["directory"]
+                )
+            except ValueError:
+                pass
+            self.storage.config["directory"] = self.storage.config["directory"].strip(
+                "/"
+            )
+
         # check if URL is an existing experiment
         derived_from = None
         try:
@@ -369,7 +398,7 @@ class Execution(Jsonable):
 
     def set_result(self, result, index=None):
         if index is None:
-            index = len(self.schedule) - 1
+            index = len(self.schedule._result)
         if isinstance(result, ExecutionException):
             self.failures += 1
             if self._behavior["raise_exceptions"]:
