@@ -1,6 +1,6 @@
 import os
 import shutil
-
+import pytest
 from machinable.project import Project
 
 
@@ -25,10 +25,8 @@ def test_project_config():
 def test_project_name():
     test_project = Project("./test_project")
     assert test_project.name == "test_project"
-    test_project.set_name("test")
-    assert test_project.name == "test"
-    test_project.name = "name"
-    assert test_project.name == "name"
+    with pytest.raises(ValueError):
+        name = Project({"name": "invalid$"}).name
 
 
 def test_project_parse_imports():
@@ -106,6 +104,10 @@ def test_parse_config():
     # args from imports correct?
     assert config["components"]["+.fooba.models.baseline"]["args"]["overwrite"]
 
+    # check scoped inheritance
+    assert config["components"]["inheritance_from_other_section"]["args"]["alpha"] == 0
+    assert config["components"]["inheritance_from_outer_section"]["args"]["id"] == -1
+
     # is importable?
     for k, v in config["components"].items():
         if k.find("@") != -1:
